#privatenotesitem_form textarea,
.inline-PrivateNotesItem textarea {
  background-color: #f9ffd0;
  font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
  font-size: 14px;
  line-height: 1.42857;
  color: #555;
}
